@@ -7,8 +7,8 @@ object with the metadata as attributes.
 from metamoth.metamoth import parse_metadata
 
 __author__ = """Santiago Martinez Balvanera"""
-__email__ = "santiago.balvanera.20@ucl.ac.com"
-__version__ = "0.1.0"
+__email__ = "santiago.balvanera.20@ucl.ac.uk"
+__version__ = "1.0.1"
 
 
 __all__ = ["parse_metadata"]
